# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import (
    DtmfType,
    AnchorsiteOverride,
    texml_application_list_params,
    texml_application_create_params,
    texml_application_update_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.dtmf_type import DtmfType
from ..types.texml_application import TexmlApplication
from ..types.anchorsite_override import AnchorsiteOverride
from ..types.texml_application_create_response import TexmlApplicationCreateResponse
from ..types.texml_application_delete_response import TexmlApplicationDeleteResponse
from ..types.texml_application_update_response import TexmlApplicationUpdateResponse
from ..types.texml_application_retrieve_response import TexmlApplicationRetrieveResponse

__all__ = ["TexmlApplicationsResource", "AsyncTexmlApplicationsResource"]


class TexmlApplicationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TexmlApplicationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return TexmlApplicationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TexmlApplicationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return TexmlApplicationsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        friendly_name: str,
        voice_url: str,
        active: bool | Omit = omit,
        anchorsite_override: AnchorsiteOverride | Omit = omit,
        call_cost_in_webhooks: bool | Omit = omit,
        dtmf_type: DtmfType | Omit = omit,
        first_command_timeout: bool | Omit = omit,
        first_command_timeout_secs: int | Omit = omit,
        inbound: texml_application_create_params.Inbound | Omit = omit,
        outbound: texml_application_create_params.Outbound | Omit = omit,
        status_callback: str | Omit = omit,
        status_callback_method: Literal["get", "post"] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        voice_fallback_url: str | Omit = omit,
        voice_method: Literal["get", "post"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationCreateResponse:
        """
        Creates a TeXML Application.

        Args:
          friendly_name: A user-assigned name to help manage the application.

          voice_url: URL to which Telnyx will deliver your XML Translator webhooks.

          active: Specifies whether the connection can be used.

          anchorsite_override: `Latency` directs Telnyx to route media through the site with the lowest
              round-trip time to the user's connection. Telnyx calculates this time using ICMP
              ping messages. This can be disabled by specifying a site to handle all media.

          call_cost_in_webhooks: Specifies if call cost webhooks should be sent for this TeXML Application.

          dtmf_type: Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF
              digits sent to Telnyx will be accepted in all formats.

          first_command_timeout: Specifies whether calls to phone numbers associated with this connection should
              hangup after timing out.

          first_command_timeout_secs: Specifies how many seconds to wait before timing out a dial command.

          status_callback: URL for Telnyx to send requests to containing information about call progress
              events.

          status_callback_method: HTTP request method Telnyx should use when requesting the status_callback URL.

          tags: Tags associated with the Texml Application.

          voice_fallback_url: URL to which Telnyx will deliver your XML Translator webhooks if we get an error
              response from your voice_url.

          voice_method: HTTP request method Telnyx will use to interact with your XML Translator
              webhooks. Either 'get' or 'post'.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/texml_applications",
            body=maybe_transform(
                {
                    "friendly_name": friendly_name,
                    "voice_url": voice_url,
                    "active": active,
                    "anchorsite_override": anchorsite_override,
                    "call_cost_in_webhooks": call_cost_in_webhooks,
                    "dtmf_type": dtmf_type,
                    "first_command_timeout": first_command_timeout,
                    "first_command_timeout_secs": first_command_timeout_secs,
                    "inbound": inbound,
                    "outbound": outbound,
                    "status_callback": status_callback,
                    "status_callback_method": status_callback_method,
                    "tags": tags,
                    "voice_fallback_url": voice_fallback_url,
                    "voice_method": voice_method,
                },
                texml_application_create_params.TexmlApplicationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationRetrieveResponse:
        """
        Retrieves the details of an existing TeXML Application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/texml_applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        friendly_name: str,
        voice_url: str,
        active: bool | Omit = omit,
        anchorsite_override: AnchorsiteOverride | Omit = omit,
        call_cost_in_webhooks: bool | Omit = omit,
        dtmf_type: DtmfType | Omit = omit,
        first_command_timeout: bool | Omit = omit,
        first_command_timeout_secs: int | Omit = omit,
        inbound: texml_application_update_params.Inbound | Omit = omit,
        outbound: texml_application_update_params.Outbound | Omit = omit,
        status_callback: str | Omit = omit,
        status_callback_method: Literal["get", "post"] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        voice_fallback_url: str | Omit = omit,
        voice_method: Literal["get", "post"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationUpdateResponse:
        """
        Updates settings of an existing TeXML Application.

        Args:
          friendly_name: A user-assigned name to help manage the application.

          voice_url: URL to which Telnyx will deliver your XML Translator webhooks.

          active: Specifies whether the connection can be used.

          anchorsite_override: `Latency` directs Telnyx to route media through the site with the lowest
              round-trip time to the user's connection. Telnyx calculates this time using ICMP
              ping messages. This can be disabled by specifying a site to handle all media.

          call_cost_in_webhooks: Specifies if call cost webhooks should be sent for this TeXML Application.

          dtmf_type: Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF
              digits sent to Telnyx will be accepted in all formats.

          first_command_timeout: Specifies whether calls to phone numbers associated with this connection should
              hangup after timing out.

          first_command_timeout_secs: Specifies how many seconds to wait before timing out a dial command.

          status_callback: URL for Telnyx to send requests to containing information about call progress
              events.

          status_callback_method: HTTP request method Telnyx should use when requesting the status_callback URL.

          tags: Tags associated with the Texml Application.

          voice_fallback_url: URL to which Telnyx will deliver your XML Translator webhooks if we get an error
              response from your voice_url.

          voice_method: HTTP request method Telnyx will use to interact with your XML Translator
              webhooks. Either 'get' or 'post'.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            f"/texml_applications/{id}",
            body=maybe_transform(
                {
                    "friendly_name": friendly_name,
                    "voice_url": voice_url,
                    "active": active,
                    "anchorsite_override": anchorsite_override,
                    "call_cost_in_webhooks": call_cost_in_webhooks,
                    "dtmf_type": dtmf_type,
                    "first_command_timeout": first_command_timeout,
                    "first_command_timeout_secs": first_command_timeout_secs,
                    "inbound": inbound,
                    "outbound": outbound,
                    "status_callback": status_callback,
                    "status_callback_method": status_callback_method,
                    "tags": tags,
                    "voice_fallback_url": voice_fallback_url,
                    "voice_method": voice_method,
                },
                texml_application_update_params.TexmlApplicationUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationUpdateResponse,
        )

    def list(
        self,
        *,
        filter: texml_application_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: Literal["created_at", "friendly_name", "active"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[TexmlApplication]:
        """
        Returns a list of your TeXML Applications.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[outbound_voice_profile_id], filter[friendly_name]

          sort: Specifies the sort order for results. By default sorting direction is ascending.
              To have the results sorted in descending order add the <code> -</code>
              prefix.<br/><br/> That is: <ul>

                <li>
                  <code>friendly_name</code>: sorts the result by the
                  <code>friendly_name</code> field in ascending order.
                </li>

                <li>
                  <code>-friendly_name</code>: sorts the result by the
                  <code>friendly_name</code> field in descending order.
                </li>
              </ul> <br/> If not given, results are sorted by <code>created_at</code> in descending order.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/texml_applications",
            page=SyncDefaultFlatPagination[TexmlApplication],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    texml_application_list_params.TexmlApplicationListParams,
                ),
            ),
            model=TexmlApplication,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationDeleteResponse:
        """
        Deletes a TeXML Application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/texml_applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationDeleteResponse,
        )


class AsyncTexmlApplicationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTexmlApplicationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTexmlApplicationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTexmlApplicationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncTexmlApplicationsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        friendly_name: str,
        voice_url: str,
        active: bool | Omit = omit,
        anchorsite_override: AnchorsiteOverride | Omit = omit,
        call_cost_in_webhooks: bool | Omit = omit,
        dtmf_type: DtmfType | Omit = omit,
        first_command_timeout: bool | Omit = omit,
        first_command_timeout_secs: int | Omit = omit,
        inbound: texml_application_create_params.Inbound | Omit = omit,
        outbound: texml_application_create_params.Outbound | Omit = omit,
        status_callback: str | Omit = omit,
        status_callback_method: Literal["get", "post"] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        voice_fallback_url: str | Omit = omit,
        voice_method: Literal["get", "post"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationCreateResponse:
        """
        Creates a TeXML Application.

        Args:
          friendly_name: A user-assigned name to help manage the application.

          voice_url: URL to which Telnyx will deliver your XML Translator webhooks.

          active: Specifies whether the connection can be used.

          anchorsite_override: `Latency` directs Telnyx to route media through the site with the lowest
              round-trip time to the user's connection. Telnyx calculates this time using ICMP
              ping messages. This can be disabled by specifying a site to handle all media.

          call_cost_in_webhooks: Specifies if call cost webhooks should be sent for this TeXML Application.

          dtmf_type: Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF
              digits sent to Telnyx will be accepted in all formats.

          first_command_timeout: Specifies whether calls to phone numbers associated with this connection should
              hangup after timing out.

          first_command_timeout_secs: Specifies how many seconds to wait before timing out a dial command.

          status_callback: URL for Telnyx to send requests to containing information about call progress
              events.

          status_callback_method: HTTP request method Telnyx should use when requesting the status_callback URL.

          tags: Tags associated with the Texml Application.

          voice_fallback_url: URL to which Telnyx will deliver your XML Translator webhooks if we get an error
              response from your voice_url.

          voice_method: HTTP request method Telnyx will use to interact with your XML Translator
              webhooks. Either 'get' or 'post'.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/texml_applications",
            body=await async_maybe_transform(
                {
                    "friendly_name": friendly_name,
                    "voice_url": voice_url,
                    "active": active,
                    "anchorsite_override": anchorsite_override,
                    "call_cost_in_webhooks": call_cost_in_webhooks,
                    "dtmf_type": dtmf_type,
                    "first_command_timeout": first_command_timeout,
                    "first_command_timeout_secs": first_command_timeout_secs,
                    "inbound": inbound,
                    "outbound": outbound,
                    "status_callback": status_callback,
                    "status_callback_method": status_callback_method,
                    "tags": tags,
                    "voice_fallback_url": voice_fallback_url,
                    "voice_method": voice_method,
                },
                texml_application_create_params.TexmlApplicationCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationRetrieveResponse:
        """
        Retrieves the details of an existing TeXML Application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/texml_applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        friendly_name: str,
        voice_url: str,
        active: bool | Omit = omit,
        anchorsite_override: AnchorsiteOverride | Omit = omit,
        call_cost_in_webhooks: bool | Omit = omit,
        dtmf_type: DtmfType | Omit = omit,
        first_command_timeout: bool | Omit = omit,
        first_command_timeout_secs: int | Omit = omit,
        inbound: texml_application_update_params.Inbound | Omit = omit,
        outbound: texml_application_update_params.Outbound | Omit = omit,
        status_callback: str | Omit = omit,
        status_callback_method: Literal["get", "post"] | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        voice_fallback_url: str | Omit = omit,
        voice_method: Literal["get", "post"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationUpdateResponse:
        """
        Updates settings of an existing TeXML Application.

        Args:
          friendly_name: A user-assigned name to help manage the application.

          voice_url: URL to which Telnyx will deliver your XML Translator webhooks.

          active: Specifies whether the connection can be used.

          anchorsite_override: `Latency` directs Telnyx to route media through the site with the lowest
              round-trip time to the user's connection. Telnyx calculates this time using ICMP
              ping messages. This can be disabled by specifying a site to handle all media.

          call_cost_in_webhooks: Specifies if call cost webhooks should be sent for this TeXML Application.

          dtmf_type: Sets the type of DTMF digits sent from Telnyx to this Connection. Note that DTMF
              digits sent to Telnyx will be accepted in all formats.

          first_command_timeout: Specifies whether calls to phone numbers associated with this connection should
              hangup after timing out.

          first_command_timeout_secs: Specifies how many seconds to wait before timing out a dial command.

          status_callback: URL for Telnyx to send requests to containing information about call progress
              events.

          status_callback_method: HTTP request method Telnyx should use when requesting the status_callback URL.

          tags: Tags associated with the Texml Application.

          voice_fallback_url: URL to which Telnyx will deliver your XML Translator webhooks if we get an error
              response from your voice_url.

          voice_method: HTTP request method Telnyx will use to interact with your XML Translator
              webhooks. Either 'get' or 'post'.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            f"/texml_applications/{id}",
            body=await async_maybe_transform(
                {
                    "friendly_name": friendly_name,
                    "voice_url": voice_url,
                    "active": active,
                    "anchorsite_override": anchorsite_override,
                    "call_cost_in_webhooks": call_cost_in_webhooks,
                    "dtmf_type": dtmf_type,
                    "first_command_timeout": first_command_timeout,
                    "first_command_timeout_secs": first_command_timeout_secs,
                    "inbound": inbound,
                    "outbound": outbound,
                    "status_callback": status_callback,
                    "status_callback_method": status_callback_method,
                    "tags": tags,
                    "voice_fallback_url": voice_fallback_url,
                    "voice_method": voice_method,
                },
                texml_application_update_params.TexmlApplicationUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationUpdateResponse,
        )

    def list(
        self,
        *,
        filter: texml_application_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: Literal["created_at", "friendly_name", "active"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[TexmlApplication, AsyncDefaultFlatPagination[TexmlApplication]]:
        """
        Returns a list of your TeXML Applications.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[outbound_voice_profile_id], filter[friendly_name]

          sort: Specifies the sort order for results. By default sorting direction is ascending.
              To have the results sorted in descending order add the <code> -</code>
              prefix.<br/><br/> That is: <ul>

                <li>
                  <code>friendly_name</code>: sorts the result by the
                  <code>friendly_name</code> field in ascending order.
                </li>

                <li>
                  <code>-friendly_name</code>: sorts the result by the
                  <code>friendly_name</code> field in descending order.
                </li>
              </ul> <br/> If not given, results are sorted by <code>created_at</code> in descending order.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/texml_applications",
            page=AsyncDefaultFlatPagination[TexmlApplication],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    texml_application_list_params.TexmlApplicationListParams,
                ),
            ),
            model=TexmlApplication,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TexmlApplicationDeleteResponse:
        """
        Deletes a TeXML Application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/texml_applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TexmlApplicationDeleteResponse,
        )


class TexmlApplicationsResourceWithRawResponse:
    def __init__(self, texml_applications: TexmlApplicationsResource) -> None:
        self._texml_applications = texml_applications

        self.create = to_raw_response_wrapper(
            texml_applications.create,
        )
        self.retrieve = to_raw_response_wrapper(
            texml_applications.retrieve,
        )
        self.update = to_raw_response_wrapper(
            texml_applications.update,
        )
        self.list = to_raw_response_wrapper(
            texml_applications.list,
        )
        self.delete = to_raw_response_wrapper(
            texml_applications.delete,
        )


class AsyncTexmlApplicationsResourceWithRawResponse:
    def __init__(self, texml_applications: AsyncTexmlApplicationsResource) -> None:
        self._texml_applications = texml_applications

        self.create = async_to_raw_response_wrapper(
            texml_applications.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            texml_applications.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            texml_applications.update,
        )
        self.list = async_to_raw_response_wrapper(
            texml_applications.list,
        )
        self.delete = async_to_raw_response_wrapper(
            texml_applications.delete,
        )


class TexmlApplicationsResourceWithStreamingResponse:
    def __init__(self, texml_applications: TexmlApplicationsResource) -> None:
        self._texml_applications = texml_applications

        self.create = to_streamed_response_wrapper(
            texml_applications.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            texml_applications.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            texml_applications.update,
        )
        self.list = to_streamed_response_wrapper(
            texml_applications.list,
        )
        self.delete = to_streamed_response_wrapper(
            texml_applications.delete,
        )


class AsyncTexmlApplicationsResourceWithStreamingResponse:
    def __init__(self, texml_applications: AsyncTexmlApplicationsResource) -> None:
        self._texml_applications = texml_applications

        self.create = async_to_streamed_response_wrapper(
            texml_applications.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            texml_applications.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            texml_applications.update,
        )
        self.list = async_to_streamed_response_wrapper(
            texml_applications.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            texml_applications.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["BrandListParams"]


class BrandListParams(TypedDict, total=False):
    brand_id: Annotated[str, PropertyInfo(alias="brandId")]
    """Filter results by the Telnyx Brand id"""

    country: str

    display_name: Annotated[str, PropertyInfo(alias="displayName")]

    entity_type: Annotated[str, PropertyInfo(alias="entityType")]

    page: int

    records_per_page: Annotated[int, PropertyInfo(alias="recordsPerPage")]
    """number of records per page. maximum of 500"""

    sort: Literal[
        "assignedCampaignsCount",
        "-assignedCampaignsCount",
        "brandId",
        "-brandId",
        "createdAt",
        "-createdAt",
        "displayName",
        "-displayName",
        "identityStatus",
        "-identityStatus",
        "status",
        "-status",
        "tcrBrandId",
        "-tcrBrandId",
    ]
    """Specifies the sort order for results.

    If not given, results are sorted by createdAt in descending order.
    """

    state: str

    tcr_brand_id: Annotated[str, PropertyInfo(alias="tcrBrandId")]
    """Filter results by the TCR Brand id"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .actions import (
    ActionsResource,
    AsyncActionsResource,
    ActionsResourceWithRawResponse,
    AsyncActionsResourceWithRawResponse,
    ActionsResourceWithStreamingResponse,
    AsyncActionsResourceWithStreamingResponse,
)
from .messaging_hosted_number_orders import (
    MessagingHostedNumberOrdersResource,
    AsyncMessagingHostedNumberOrdersResource,
    MessagingHostedNumberOrdersResourceWithRawResponse,
    AsyncMessagingHostedNumberOrdersResourceWithRawResponse,
    MessagingHostedNumberOrdersResourceWithStreamingResponse,
    AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse,
)

__all__ = [
    "ActionsResource",
    "AsyncActionsResource",
    "ActionsResourceWithRawResponse",
    "AsyncActionsResourceWithRawResponse",
    "ActionsResourceWithStreamingResponse",
    "AsyncActionsResourceWithStreamingResponse",
    "MessagingHostedNumberOrdersResource",
    "AsyncMessagingHostedNumberOrdersResource",
    "MessagingHostedNumberOrdersResourceWithRawResponse",
    "AsyncMessagingHostedNumberOrdersResourceWithRawResponse",
    "MessagingHostedNumberOrdersResourceWithStreamingResponse",
    "AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types import (
    CallDialResponse,
    CallRetrieveStatusResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCalls:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_dial(self, client: Telnyx) -> None:
        call = client.calls.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        )
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_dial_with_all_params(self, client: Telnyx) -> None:
        call = client.calls.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
            answering_machine_detection="detect",
            answering_machine_detection_config={
                "after_greeting_silence_millis": 1000,
                "between_words_silence_millis": 1000,
                "greeting_duration_millis": 1000,
                "greeting_silence_duration_millis": 2000,
                "greeting_total_analysis_time_millis": 50000,
                "initial_silence_millis": 1000,
                "maximum_number_of_words": 1000,
                "maximum_word_length_millis": 2000,
                "silence_threshold": 512,
                "total_analysis_time_millis": 5000,
            },
            audio_url="http://www.example.com/sounds/greeting.wav",
            billing_group_id="f5586561-8ff0-4291-a0ac-84fe544797bd",
            bridge_intent=True,
            bridge_on_answer=True,
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            conference_config={
                "id": "0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
                "beep_enabled": "on_exit",
                "conference_name": "telnyx-conference",
                "early_media": False,
                "end_conference_on_exit": True,
                "hold": True,
                "hold_audio_url": "http://example.com/message.wav",
                "hold_media_name": "my_media_uploaded_to_media_storage_api",
                "mute": True,
                "soft_end_conference_on_exit": True,
                "start_conference_on_create": False,
                "start_conference_on_enter": True,
                "supervisor_role": "whisper",
                "whisper_call_control_ids": [
                    "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                    "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
                ],
            },
            custom_headers=[
                {
                    "name": "head_1",
                    "value": "val_1",
                },
                {
                    "name": "head_2",
                    "value": "val_2",
                },
            ],
            dialogflow_config={
                "analyze_sentiment": False,
                "partial_automated_agent_reply": False,
            },
            enable_dialogflow=False,
            from_display_name="Company Name",
            link_to="ilditnZK_eVysupV21KzmzN_sM29ygfauQojpm4BgFtfX5hXAcjotg==",
            media_encryption="SRTP",
            media_name="my_media_uploaded_to_media_storage_api",
            park_after_unbridge="self",
            preferred_codecs="G722,PCMU,PCMA,G729,OPUS,VP8,H264",
            record="record-from-answer",
            record_channels="single",
            record_custom_file_name="my_recording_file_name",
            record_format="wav",
            record_max_length=1000,
            record_timeout_secs=100,
            record_track="outbound",
            record_trim="trim-silence",
            send_silence_when_idle=True,
            sip_auth_password="password",
            sip_auth_username="username",
            sip_headers=[
                {
                    "name": "User-to-User",
                    "value": "12345",
                }
            ],
            sip_region="Canada",
            sip_transport_protocol="TLS",
            sound_modifications={
                "octaves": 0.1,
                "pitch": 0.8,
                "semitone": -2,
                "track": "both",
            },
            stream_bidirectional_codec="G722",
            stream_bidirectional_mode="rtp",
            stream_bidirectional_sampling_rate=16000,
            stream_bidirectional_target_legs="both",
            stream_codec="PCMA",
            stream_establish_before_call_originate=True,
            stream_track="both_tracks",
            stream_url="wss://www.example.com/websocket",
            supervise_call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="barge",
            time_limit_secs=60,
            timeout_secs=60,
            transcription=True,
            transcription_config={
                "client_state": "aGF2ZSBhIG5pY2UgZGF5ID1d",
                "command_id": "891510ac-f3e4-11e8-af5b-de00688a4901",
                "transcription_engine": "Google",
                "transcription_engine_config": {
                    "enable_speaker_diarization": True,
                    "hints": ["string"],
                    "interim_results": True,
                    "language": "en",
                    "max_speaker_count": 4,
                    "min_speaker_count": 4,
                    "model": "latest_long",
                    "profanity_filter": True,
                    "speech_context": [
                        {
                            "boost": 1,
                            "phrases": ["string"],
                        }
                    ],
                    "transcription_engine": "Google",
                    "use_enhanced": True,
                },
                "transcription_tracks": "both",
            },
            webhook_url="https://www.example.com/server-b/",
            webhook_url_method="POST",
        )
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_dial(self, client: Telnyx) -> None:
        response = client.calls.with_raw_response.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_dial(self, client: Telnyx) -> None:
        with client.calls.with_streaming_response.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallDialResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve_status(self, client: Telnyx) -> None:
        call = client.calls.retrieve_status(
            "call_control_id",
        )
        assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve_status(self, client: Telnyx) -> None:
        response = client.calls.with_raw_response.retrieve_status(
            "call_control_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = response.parse()
        assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_status(self, client: Telnyx) -> None:
        with client.calls.with_streaming_response.retrieve_status(
            "call_control_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = response.parse()
            assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve_status(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_control_id` but received ''"):
            client.calls.with_raw_response.retrieve_status(
                "",
            )


class TestAsyncCalls:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_dial(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.calls.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        )
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_dial_with_all_params(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.calls.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
            answering_machine_detection="detect",
            answering_machine_detection_config={
                "after_greeting_silence_millis": 1000,
                "between_words_silence_millis": 1000,
                "greeting_duration_millis": 1000,
                "greeting_silence_duration_millis": 2000,
                "greeting_total_analysis_time_millis": 50000,
                "initial_silence_millis": 1000,
                "maximum_number_of_words": 1000,
                "maximum_word_length_millis": 2000,
                "silence_threshold": 512,
                "total_analysis_time_millis": 5000,
            },
            audio_url="http://www.example.com/sounds/greeting.wav",
            billing_group_id="f5586561-8ff0-4291-a0ac-84fe544797bd",
            bridge_intent=True,
            bridge_on_answer=True,
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            conference_config={
                "id": "0ccc7b54-4df3-4bca-a65a-3da1ecc777f0",
                "beep_enabled": "on_exit",
                "conference_name": "telnyx-conference",
                "early_media": False,
                "end_conference_on_exit": True,
                "hold": True,
                "hold_audio_url": "http://example.com/message.wav",
                "hold_media_name": "my_media_uploaded_to_media_storage_api",
                "mute": True,
                "soft_end_conference_on_exit": True,
                "start_conference_on_create": False,
                "start_conference_on_enter": True,
                "supervisor_role": "whisper",
                "whisper_call_control_ids": [
                    "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                    "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
                ],
            },
            custom_headers=[
                {
                    "name": "head_1",
                    "value": "val_1",
                },
                {
                    "name": "head_2",
                    "value": "val_2",
                },
            ],
            dialogflow_config={
                "analyze_sentiment": False,
                "partial_automated_agent_reply": False,
            },
            enable_dialogflow=False,
            from_display_name="Company Name",
            link_to="ilditnZK_eVysupV21KzmzN_sM29ygfauQojpm4BgFtfX5hXAcjotg==",
            media_encryption="SRTP",
            media_name="my_media_uploaded_to_media_storage_api",
            park_after_unbridge="self",
            preferred_codecs="G722,PCMU,PCMA,G729,OPUS,VP8,H264",
            record="record-from-answer",
            record_channels="single",
            record_custom_file_name="my_recording_file_name",
            record_format="wav",
            record_max_length=1000,
            record_timeout_secs=100,
            record_track="outbound",
            record_trim="trim-silence",
            send_silence_when_idle=True,
            sip_auth_password="password",
            sip_auth_username="username",
            sip_headers=[
                {
                    "name": "User-to-User",
                    "value": "12345",
                }
            ],
            sip_region="Canada",
            sip_transport_protocol="TLS",
            sound_modifications={
                "octaves": 0.1,
                "pitch": 0.8,
                "semitone": -2,
                "track": "both",
            },
            stream_bidirectional_codec="G722",
            stream_bidirectional_mode="rtp",
            stream_bidirectional_sampling_rate=16000,
            stream_bidirectional_target_legs="both",
            stream_codec="PCMA",
            stream_establish_before_call_originate=True,
            stream_track="both_tracks",
            stream_url="wss://www.example.com/websocket",
            supervise_call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="barge",
            time_limit_secs=60,
            timeout_secs=60,
            transcription=True,
            transcription_config={
                "client_state": "aGF2ZSBhIG5pY2UgZGF5ID1d",
                "command_id": "891510ac-f3e4-11e8-af5b-de00688a4901",
                "transcription_engine": "Google",
                "transcription_engine_config": {
                    "enable_speaker_diarization": True,
                    "hints": ["string"],
                    "interim_results": True,
                    "language": "en",
                    "max_speaker_count": 4,
                    "min_speaker_count": 4,
                    "model": "latest_long",
                    "profanity_filter": True,
                    "speech_context": [
                        {
                            "boost": 1,
                            "phrases": ["string"],
                        }
                    ],
                    "transcription_engine": "Google",
                    "use_enhanced": True,
                },
                "transcription_tracks": "both",
            },
            webhook_url="https://www.example.com/server-b/",
            webhook_url_method="POST",
        )
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_dial(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.calls.with_raw_response.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallDialResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_dial(self, async_client: AsyncTelnyx) -> None:
        async with async_client.calls.with_streaming_response.dial(
            connection_id="7267xxxxxxxxxxxxxx",
            from_="+18005550101",
            to="+18005550100 or sip:username@sip.telnyx.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallDialResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve_status(self, async_client: AsyncTelnyx) -> None:
        call = await async_client.calls.retrieve_status(
            "call_control_id",
        )
        assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_status(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.calls.with_raw_response.retrieve_status(
            "call_control_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        call = await response.parse()
        assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_status(self, async_client: AsyncTelnyx) -> None:
        async with async_client.calls.with_streaming_response.retrieve_status(
            "call_control_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            call = await response.parse()
            assert_matches_type(CallRetrieveStatusResponse, call, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve_status(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `call_control_id` but received ''"):
            await async_client.calls.with_raw_response.retrieve_status(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ....._models import BaseModel

__all__ = ["VoiceRetrieveFieldsResponse"]


class VoiceRetrieveFieldsResponse(BaseModel):
    """Available CDR report fields grouped by category"""

    billing: Optional[List[str]] = FieldInfo(alias="Billing", default=None)
    """Cost and billing related information"""

    interaction_data: Optional[List[str]] = FieldInfo(alias="Interaction Data", default=None)
    """Fields related to call interaction and basic call information"""

    number_information: Optional[List[str]] = FieldInfo(alias="Number Information", default=None)
    """Geographic and routing information for phone numbers"""

    telephony_data: Optional[List[str]] = FieldInfo(alias="Telephony Data", default=None)
    """Technical telephony and call control information"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import TypedDict

__all__ = ["GlobalIPCreateParams"]


class GlobalIPCreateParams(TypedDict, total=False):
    description: str
    """A user specified description for the address."""

    name: str
    """A user specified name for the address."""

    ports: Dict[str, object]
    """A Global IP ports grouped by protocol code."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["RunCreateResponse", "Data"]


class Data(BaseModel):
    mission_id: str

    run_id: str

    started_at: datetime

    status: Literal["pending", "running", "paused", "succeeded", "failed", "cancelled"]

    updated_at: datetime

    error: Optional[str] = None

    finished_at: Optional[datetime] = None

    input: Optional[Dict[str, object]] = None

    metadata: Optional[Dict[str, object]] = None

    result_payload: Optional[Dict[str, object]] = None

    result_summary: Optional[str] = None


class RunCreateResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference_participant_playback_ended import ConferenceParticipantPlaybackEnded

__all__ = ["ConferenceParticipantPlaybackEndedWebhookEvent"]


class ConferenceParticipantPlaybackEndedWebhookEvent(BaseModel):
    data: Optional[ConferenceParticipantPlaybackEnded] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from telnyx.types.ai.missions import (
    RunListResponse,
    RunCreateResponse,
    RunUpdateResponse,
    RunListRunsResponse,
    RunPauseRunResponse,
    RunRetrieveResponse,
    RunCancelRunResponse,
    RunResumeRunResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestRuns:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={"foo": "bar"},
            metadata={"foo": "bar"},
        )
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunCreateResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.create(
                mission_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunRetrieveResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunRetrieveResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunRetrieveResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.retrieve(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.ai.missions.runs.with_raw_response.retrieve(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            error="error",
            metadata={"foo": "bar"},
            result_payload={"foo": "bar"},
            result_summary="result_summary",
            status="pending",
        )
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunUpdateResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.update(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.ai.missions.runs.with_raw_response.update(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(SyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            page_number=1,
            page_size=1,
            status="status",
        )
        assert_matches_type(SyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[RunListResponse], run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.list(
                mission_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_cancel_run(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunCancelRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_cancel_run(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunCancelRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_cancel_run(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunCancelRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_cancel_run(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.cancel_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.ai.missions.runs.with_raw_response.cancel_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_runs(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.list_runs()
        assert_matches_type(SyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_runs_with_all_params(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.list_runs(
            page_number=1,
            page_size=1,
            status="status",
        )
        assert_matches_type(SyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_runs(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.list_runs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_runs(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.list_runs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_pause_run(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunPauseRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_pause_run(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunPauseRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_pause_run(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunPauseRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_pause_run(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.pause_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.ai.missions.runs.with_raw_response.pause_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_resume_run(self, client: Telnyx) -> None:
        run = client.ai.missions.runs.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunResumeRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_resume_run(self, client: Telnyx) -> None:
        response = client.ai.missions.runs.with_raw_response.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = response.parse()
        assert_matches_type(RunResumeRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_resume_run(self, client: Telnyx) -> None:
        with client.ai.missions.runs.with_streaming_response.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = response.parse()
            assert_matches_type(RunResumeRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_resume_run(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.runs.with_raw_response.resume_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            client.ai.missions.runs.with_raw_response.resume_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )


class TestAsyncRuns:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            input={"foo": "bar"},
            metadata={"foo": "bar"},
        )
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunCreateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.create(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunCreateResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.create(
                mission_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunRetrieveResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunRetrieveResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.retrieve(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunRetrieveResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.retrieve(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.retrieve(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            error="error",
            metadata={"foo": "bar"},
            result_payload={"foo": "bar"},
            result_summary="result_summary",
            status="pending",
        )
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunUpdateResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.update(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunUpdateResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.update(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.update(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AsyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            page_number=1,
            page_size=1,
            status="status",
        )
        assert_matches_type(AsyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[RunListResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.list(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[RunListResponse], run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.list(
                mission_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_cancel_run(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunCancelRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_cancel_run(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunCancelRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_cancel_run(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.cancel_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunCancelRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_cancel_run(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.cancel_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.cancel_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_runs(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.list_runs()
        assert_matches_type(AsyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_runs_with_all_params(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.list_runs(
            page_number=1,
            page_size=1,
            status="status",
        )
        assert_matches_type(AsyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_runs(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.list_runs()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_runs(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.list_runs() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[RunListRunsResponse], run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_pause_run(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunPauseRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_pause_run(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunPauseRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_pause_run(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.pause_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunPauseRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_pause_run(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.pause_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.pause_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_resume_run(self, async_client: AsyncTelnyx) -> None:
        run = await async_client.ai.missions.runs.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(RunResumeRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_resume_run(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.runs.with_raw_response.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        run = await response.parse()
        assert_matches_type(RunResumeRunResponse, run, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_resume_run(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.runs.with_streaming_response.resume_run(
            run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            run = await response.parse()
            assert_matches_type(RunResumeRunResponse, run, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_resume_run(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.resume_run(
                run_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `run_id` but received ''"):
            await async_client.ai.missions.runs.with_raw_response.resume_run(
                run_id="",
                mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["ExternalConnectionUpdateLocationParams"]


class ExternalConnectionUpdateLocationParams(TypedDict, total=False):
    id: Required[str]

    static_emergency_address_id: Required[str]
    """A new static emergency address ID to update the location with"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.messaging_10dlc import TelnyxCampaignCsp

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestCampaignBuilder:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_submit(self, client: Telnyx) -> None:
        campaign_builder = client.messaging_10dlc.campaign_builder.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_submit_with_all_params(self, client: Telnyx) -> None:
        campaign_builder = client.messaging_10dlc.campaign_builder.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
            age_gated=True,
            auto_renewal=True,
            direct_lending=True,
            embedded_link=True,
            embedded_link_sample="embeddedLinkSample",
            embedded_phone=True,
            help_keywords="helpKeywords",
            help_message="helpMessage",
            message_flow="messageFlow",
            mno_ids=[0],
            number_pool=True,
            optin_keywords="optinKeywords",
            optin_message="optinMessage",
            optout_keywords="optoutKeywords",
            optout_message="optoutMessage",
            privacy_policy_link="privacyPolicyLink",
            reference_id="referenceId",
            reseller_id="resellerId",
            sample1="sample1",
            sample2="sample2",
            sample3="sample3",
            sample4="sample4",
            sample5="sample5",
            subscriber_help=True,
            subscriber_optin=True,
            subscriber_optout=True,
            sub_usecases=["string"],
            tag=["string"],
            terms_and_conditions=True,
            terms_and_conditions_link="termsAndConditionsLink",
            webhook_failover_url="https://webhook.com/93711262-23e5-4048-a966-c0b2a16d5963",
            webhook_url="https://webhook.com/67ea78a8-9f32-4d04-b62d-f9502e8e5f93",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_submit(self, client: Telnyx) -> None:
        response = client.messaging_10dlc.campaign_builder.with_raw_response.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign_builder = response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_submit(self, client: Telnyx) -> None:
        with client.messaging_10dlc.campaign_builder.with_streaming_response.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign_builder = response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncCampaignBuilder:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_submit(self, async_client: AsyncTelnyx) -> None:
        campaign_builder = await async_client.messaging_10dlc.campaign_builder.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_submit_with_all_params(self, async_client: AsyncTelnyx) -> None:
        campaign_builder = await async_client.messaging_10dlc.campaign_builder.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
            age_gated=True,
            auto_renewal=True,
            direct_lending=True,
            embedded_link=True,
            embedded_link_sample="embeddedLinkSample",
            embedded_phone=True,
            help_keywords="helpKeywords",
            help_message="helpMessage",
            message_flow="messageFlow",
            mno_ids=[0],
            number_pool=True,
            optin_keywords="optinKeywords",
            optin_message="optinMessage",
            optout_keywords="optoutKeywords",
            optout_message="optoutMessage",
            privacy_policy_link="privacyPolicyLink",
            reference_id="referenceId",
            reseller_id="resellerId",
            sample1="sample1",
            sample2="sample2",
            sample3="sample3",
            sample4="sample4",
            sample5="sample5",
            subscriber_help=True,
            subscriber_optin=True,
            subscriber_optout=True,
            sub_usecases=["string"],
            tag=["string"],
            terms_and_conditions=True,
            terms_and_conditions_link="termsAndConditionsLink",
            webhook_failover_url="https://webhook.com/93711262-23e5-4048-a966-c0b2a16d5963",
            webhook_url="https://webhook.com/67ea78a8-9f32-4d04-b62d-f9502e8e5f93",
        )
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_submit(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_10dlc.campaign_builder.with_raw_response.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        campaign_builder = await response.parse()
        assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_submit(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_10dlc.campaign_builder.with_streaming_response.submit(
            brand_id="brandId",
            description="description",
            usecase="usecase",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            campaign_builder = await response.parse()
            assert_matches_type(TelnyxCampaignCsp, campaign_builder, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["OAuthRetrieveResponse", "Data", "DataRequestedScope"]


class DataRequestedScope(BaseModel):
    id: Optional[str] = None
    """Scope ID"""

    description: Optional[str] = None
    """Scope description"""

    name: Optional[str] = None
    """Scope name"""


class Data(BaseModel):
    client_id: Optional[str] = None
    """Client ID"""

    logo_uri: Optional[str] = None
    """URL of the client logo"""

    name: Optional[str] = None
    """Client name"""

    policy_uri: Optional[str] = None
    """URL of the client's privacy policy"""

    redirect_uri: Optional[str] = None
    """The redirect URI for this authorization"""

    requested_scopes: Optional[List[DataRequestedScope]] = None

    tos_uri: Optional[str] = None
    """URL of the client's terms of service"""

    verified: Optional[bool] = None
    """Whether the client is verified"""


class OAuthRetrieveResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["MissionCreateResponse", "Data"]


class Data(BaseModel):
    created_at: datetime

    execution_mode: Literal["external", "managed"]

    mission_id: str

    name: str

    updated_at: datetime

    description: Optional[str] = None

    instructions: Optional[str] = None

    metadata: Optional[Dict[str, object]] = None

    model: Optional[str] = None


class MissionCreateResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .actions import (
    ActionsResource,
    AsyncActionsResource,
    ActionsResourceWithRawResponse,
    AsyncActionsResourceWithRawResponse,
    ActionsResourceWithStreamingResponse,
    AsyncActionsResourceWithStreamingResponse,
)
from .number_reservations import (
    NumberReservationsResource,
    AsyncNumberReservationsResource,
    NumberReservationsResourceWithRawResponse,
    AsyncNumberReservationsResourceWithRawResponse,
    NumberReservationsResourceWithStreamingResponse,
    AsyncNumberReservationsResourceWithStreamingResponse,
)

__all__ = [
    "ActionsResource",
    "AsyncActionsResource",
    "ActionsResourceWithRawResponse",
    "AsyncActionsResourceWithRawResponse",
    "ActionsResourceWithStreamingResponse",
    "AsyncActionsResourceWithStreamingResponse",
    "NumberReservationsResource",
    "AsyncNumberReservationsResource",
    "NumberReservationsResourceWithRawResponse",
    "AsyncNumberReservationsResourceWithRawResponse",
    "NumberReservationsResourceWithStreamingResponse",
    "AsyncNumberReservationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .oauth_grant import OAuthGrant

__all__ = ["OAuthGrantRetrieveResponse"]


class OAuthGrantRetrieveResponse(BaseModel):
    data: Optional[OAuthGrant] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["StreamBidirectionalMode"]

StreamBidirectionalMode: TypeAlias = Literal["mp3", "rtp"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["ActionSwitchSupervisorRoleParams"]


class ActionSwitchSupervisorRoleParams(TypedDict, total=False):
    role: Required[Literal["barge", "whisper", "monitor"]]
    """The supervisor role to switch to.

    'barge' allows speaking to both parties, 'whisper' allows speaking to caller
    only, 'monitor' allows listening only.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .notification_channel import NotificationChannel

__all__ = ["NotificationChannelRetrieveResponse"]


class NotificationChannelRetrieveResponse(BaseModel):
    data: Optional[NotificationChannel] = None
    """A Notification Channel"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...types import recording_list_params
from .actions import (
    ActionsResource,
    AsyncActionsResource,
    ActionsResourceWithRawResponse,
    AsyncActionsResourceWithRawResponse,
    ActionsResourceWithStreamingResponse,
    AsyncActionsResourceWithStreamingResponse,
)
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.recording_response_data import RecordingResponseData
from ...types.recording_delete_response import RecordingDeleteResponse
from ...types.recording_retrieve_response import RecordingRetrieveResponse

__all__ = ["RecordingsResource", "AsyncRecordingsResource"]


class RecordingsResource(SyncAPIResource):
    @cached_property
    def actions(self) -> ActionsResource:
        return ActionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> RecordingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return RecordingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RecordingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return RecordingsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        recording_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordingRetrieveResponse:
        """
        Retrieves the details of an existing call recording.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recording_id:
            raise ValueError(f"Expected a non-empty value for `recording_id` but received {recording_id!r}")
        return self._get(
            f"/recordings/{recording_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordingRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: recording_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[RecordingResponseData]:
        """
        Returns a list of your call recordings.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[conference_id], filter[created_at][gte], filter[created_at][lte],
              filter[call_leg_id], filter[call_session_id], filter[from], filter[to],
              filter[connection_id], filter[sip_call_id]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/recordings",
            page=SyncDefaultFlatPagination[RecordingResponseData],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    recording_list_params.RecordingListParams,
                ),
            ),
            model=RecordingResponseData,
        )

    def delete(
        self,
        recording_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordingDeleteResponse:
        """
        Permanently deletes a call recording.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recording_id:
            raise ValueError(f"Expected a non-empty value for `recording_id` but received {recording_id!r}")
        return self._delete(
            f"/recordings/{recording_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordingDeleteResponse,
        )


class AsyncRecordingsResource(AsyncAPIResource):
    @cached_property
    def actions(self) -> AsyncActionsResource:
        return AsyncActionsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncRecordingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRecordingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRecordingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncRecordingsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        recording_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordingRetrieveResponse:
        """
        Retrieves the details of an existing call recording.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recording_id:
            raise ValueError(f"Expected a non-empty value for `recording_id` but received {recording_id!r}")
        return await self._get(
            f"/recordings/{recording_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordingRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: recording_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RecordingResponseData, AsyncDefaultFlatPagination[RecordingResponseData]]:
        """
        Returns a list of your call recordings.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[conference_id], filter[created_at][gte], filter[created_at][lte],
              filter[call_leg_id], filter[call_session_id], filter[from], filter[to],
              filter[connection_id], filter[sip_call_id]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/recordings",
            page=AsyncDefaultFlatPagination[RecordingResponseData],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    recording_list_params.RecordingListParams,
                ),
            ),
            model=RecordingResponseData,
        )

    async def delete(
        self,
        recording_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RecordingDeleteResponse:
        """
        Permanently deletes a call recording.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not recording_id:
            raise ValueError(f"Expected a non-empty value for `recording_id` but received {recording_id!r}")
        return await self._delete(
            f"/recordings/{recording_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RecordingDeleteResponse,
        )


class RecordingsResourceWithRawResponse:
    def __init__(self, recordings: RecordingsResource) -> None:
        self._recordings = recordings

        self.retrieve = to_raw_response_wrapper(
            recordings.retrieve,
        )
        self.list = to_raw_response_wrapper(
            recordings.list,
        )
        self.delete = to_raw_response_wrapper(
            recordings.delete,
        )

    @cached_property
    def actions(self) -> ActionsResourceWithRawResponse:
        return ActionsResourceWithRawResponse(self._recordings.actions)


class AsyncRecordingsResourceWithRawResponse:
    def __init__(self, recordings: AsyncRecordingsResource) -> None:
        self._recordings = recordings

        self.retrieve = async_to_raw_response_wrapper(
            recordings.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            recordings.list,
        )
        self.delete = async_to_raw_response_wrapper(
            recordings.delete,
        )

    @cached_property
    def actions(self) -> AsyncActionsResourceWithRawResponse:
        return AsyncActionsResourceWithRawResponse(self._recordings.actions)


class RecordingsResourceWithStreamingResponse:
    def __init__(self, recordings: RecordingsResource) -> None:
        self._recordings = recordings

        self.retrieve = to_streamed_response_wrapper(
            recordings.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            recordings.list,
        )
        self.delete = to_streamed_response_wrapper(
            recordings.delete,
        )

    @cached_property
    def actions(self) -> ActionsResourceWithStreamingResponse:
        return ActionsResourceWithStreamingResponse(self._recordings.actions)


class AsyncRecordingsResourceWithStreamingResponse:
    def __init__(self, recordings: AsyncRecordingsResource) -> None:
        self._recordings = recordings

        self.retrieve = async_to_streamed_response_wrapper(
            recordings.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            recordings.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            recordings.delete,
        )

    @cached_property
    def actions(self) -> AsyncActionsResourceWithStreamingResponse:
        return AsyncActionsResourceWithStreamingResponse(self._recordings.actions)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.pagination import SyncDefaultPaginationForLogMessages, AsyncDefaultPaginationForLogMessages
from telnyx.types.external_connections import (
    LogMessageListResponse,
    LogMessageDismissResponse,
    LogMessageRetrieveResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestLogMessages:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        log_message = client.external_connections.log_messages.retrieve(
            "id",
        )
        assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.external_connections.log_messages.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = response.parse()
        assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.external_connections.log_messages.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = response.parse()
            assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.external_connections.log_messages.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        log_message = client.external_connections.log_messages.list()
        assert_matches_type(SyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        log_message = client.external_connections.log_messages.list(
            filter={
                "external_connection_id": "67ea7693-9cd5-4a68-8c76-abb3aa5bf5d2",
                "telephone_number": {
                    "contains": "+123",
                    "eq": "+1234567890",
                },
            },
            page_number=0,
            page_size=0,
        )
        assert_matches_type(SyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.external_connections.log_messages.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = response.parse()
        assert_matches_type(SyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.external_connections.log_messages.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = response.parse()
            assert_matches_type(
                SyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_dismiss(self, client: Telnyx) -> None:
        log_message = client.external_connections.log_messages.dismiss(
            "id",
        )
        assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_dismiss(self, client: Telnyx) -> None:
        response = client.external_connections.log_messages.with_raw_response.dismiss(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = response.parse()
        assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_dismiss(self, client: Telnyx) -> None:
        with client.external_connections.log_messages.with_streaming_response.dismiss(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = response.parse()
            assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_dismiss(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.external_connections.log_messages.with_raw_response.dismiss(
                "",
            )


class TestAsyncLogMessages:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        log_message = await async_client.external_connections.log_messages.retrieve(
            "id",
        )
        assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.external_connections.log_messages.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = await response.parse()
        assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.external_connections.log_messages.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = await response.parse()
            assert_matches_type(LogMessageRetrieveResponse, log_message, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.external_connections.log_messages.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        log_message = await async_client.external_connections.log_messages.list()
        assert_matches_type(
            AsyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        log_message = await async_client.external_connections.log_messages.list(
            filter={
                "external_connection_id": "67ea7693-9cd5-4a68-8c76-abb3aa5bf5d2",
                "telephone_number": {
                    "contains": "+123",
                    "eq": "+1234567890",
                },
            },
            page_number=0,
            page_size=0,
        )
        assert_matches_type(
            AsyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.external_connections.log_messages.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = await response.parse()
        assert_matches_type(
            AsyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"]
        )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.external_connections.log_messages.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = await response.parse()
            assert_matches_type(
                AsyncDefaultPaginationForLogMessages[LogMessageListResponse], log_message, path=["response"]
            )

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_dismiss(self, async_client: AsyncTelnyx) -> None:
        log_message = await async_client.external_connections.log_messages.dismiss(
            "id",
        )
        assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_dismiss(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.external_connections.log_messages.with_raw_response.dismiss(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        log_message = await response.parse()
        assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_dismiss(self, async_client: AsyncTelnyx) -> None:
        async with async_client.external_connections.log_messages.with_streaming_response.dismiss(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            log_message = await response.parse()
            assert_matches_type(LogMessageDismissResponse, log_message, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_dismiss(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.external_connections.log_messages.with_raw_response.dismiss(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["EventListParams", "Filter", "FilterCreatedAt"]


class EventListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[event_type], filter[portout_id], filter[created_at]
    """

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]


class FilterCreatedAt(TypedDict, total=False):
    """Filter by created_at date range using nested operations"""

    gte: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Filter by created at greater than or equal to."""

    lte: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]
    """Filter by created at less than or equal to."""


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style).

    Originally: filter[event_type], filter[portout_id], filter[created_at]
    """

    created_at: FilterCreatedAt
    """Filter by created_at date range using nested operations"""

    event_type: Literal["portout.status_changed", "portout.new_comment", "portout.foc_date_changed"]
    """Filter by event type."""

    portout_id: str
    """Filter by port-out order ID."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ...._models import BaseModel
from .insight_template import InsightTemplate

__all__ = ["InsightTemplateGroup"]


class InsightTemplateGroup(BaseModel):
    id: str

    created_at: datetime

    name: str

    description: Optional[str] = None

    insights: Optional[List[InsightTemplate]] = None

    webhook: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference_participant_playback_started import ConferenceParticipantPlaybackStarted

__all__ = ["ConferenceParticipantPlaybackStartedWebhookEvent"]


class ConferenceParticipantPlaybackStartedWebhookEvent(BaseModel):
    data: Optional[ConferenceParticipantPlaybackStarted] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["PublicInternetGatewayCreateParams"]


class PublicInternetGatewayCreateParams(TypedDict, total=False):
    name: str
    """A user specified name for the interface."""

    network_id: str
    """The id of the network associated with the interface."""

    region_code: str
    """The region interface is deployed to."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ....._models import BaseModel
from .mdr_usage_report_response_legacy import MdrUsageReportResponseLegacy

__all__ = ["MessagingDeleteResponse"]


class MessagingDeleteResponse(BaseModel):
    data: Optional[MdrUsageReportResponseLegacy] = None
    """Legacy V2 MDR usage report response"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["NetworkListParams", "Filter"]


class NetworkListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style). Originally: filter[name]"""

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style). Originally: filter[name]"""

    name: str
    """The network name to filter on."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo
from .whatsapp_media_param import WhatsappMediaParam

__all__ = [
    "MessageSendWhatsappParams",
    "WhatsappMessage",
    "WhatsappMessageContact",
    "WhatsappMessageContactAddress",
    "WhatsappMessageContactEmail",
    "WhatsappMessageContactOrg",
    "WhatsappMessageContactPhone",
    "WhatsappMessageContactURL",
    "WhatsappMessageInteractive",
    "WhatsappMessageInteractiveAction",
    "WhatsappMessageInteractiveActionButton",
    "WhatsappMessageInteractiveActionButtonReply",
    "WhatsappMessageInteractiveActionCard",
    "WhatsappMessageInteractiveActionCardAction",
    "WhatsappMessageInteractiveActionCardBody",
    "WhatsappMessageInteractiveActionCardHeader",
    "WhatsappMessageInteractiveActionParameters",
    "WhatsappMessageInteractiveActionSection",
    "WhatsappMessageInteractiveActionSectionProductItem",
    "WhatsappMessageInteractiveActionSectionRow",
    "WhatsappMessageInteractiveBody",
    "WhatsappMessageInteractiveFooter",
    "WhatsappMessageInteractiveHeader",
    "WhatsappMessageLocation",
    "WhatsappMessageReaction",
]


class MessageSendWhatsappParams(TypedDict, total=False):
    from_: Required[Annotated[str, PropertyInfo(alias="from")]]
    """Phone number in +E.164 format associated with Whatsapp account"""

    to: Required[str]
    """Phone number in +E.164 format"""

    whatsapp_message: Required[WhatsappMessage]

    type: Literal["WHATSAPP"]
    """Message type - must be set to "WHATSAPP" """

    webhook_url: str
    """The URL where webhooks related to this message will be sent."""


class WhatsappMessageContactAddress(TypedDict, total=False):
    city: str

    country: str

    country_code: str

    state: str

    street: str

    type: str

    zip: str


class WhatsappMessageContactEmail(TypedDict, total=False):
    email: str

    type: str


class WhatsappMessageContactOrg(TypedDict, total=False):
    company: str

    department: str

    title: str


class WhatsappMessageContactPhone(TypedDict, total=False):
    phone: str

    type: str

    wa_id: str


class WhatsappMessageContactURL(TypedDict, total=False):
    type: str

    url: str


class WhatsappMessageContact(TypedDict, total=False):
    addresses: Iterable[WhatsappMessageContactAddress]

    birthday: str

    emails: Iterable[WhatsappMessageContactEmail]

    name: str

    org: WhatsappMessageContactOrg

    phones: Iterable[WhatsappMessageContactPhone]

    urls: Iterable[WhatsappMessageContactURL]


class WhatsappMessageInteractiveActionButtonReply(TypedDict, total=False):
    id: str
    """unique identifier for each button, 256 character maximum"""

    title: str
    """button label, 20 character maximum"""


class WhatsappMessageInteractiveActionButton(TypedDict, total=False):
    reply: WhatsappMessageInteractiveActionButtonReply

    type: Literal["reply"]


class WhatsappMessageInteractiveActionCardAction(TypedDict, total=False):
    catalog_id: str
    """the unique ID of the catalog"""

    product_retailer_id: str
    """the unique retailer ID of the product"""


class WhatsappMessageInteractiveActionCardBody(TypedDict, total=False):
    text: str
    """160 character maximum, up to 2 line breaks"""


class WhatsappMessageInteractiveActionCardHeader(TypedDict, total=False):
    image: WhatsappMediaParam

    type: Literal["image", "video"]

    video: WhatsappMediaParam


class WhatsappMessageInteractiveActionCard(TypedDict, total=False):
    action: WhatsappMessageInteractiveActionCardAction

    body: WhatsappMessageInteractiveActionCardBody

    card_index: int
    """unique index for each card (0-9)"""

    header: WhatsappMessageInteractiveActionCardHeader

    type: Literal["cta_url"]


class WhatsappMessageInteractiveActionParameters(TypedDict, total=False):
    display_text: str
    """button label text, 20 character maximum"""

    url: str
    """button URL to load when tapped by the user"""


class WhatsappMessageInteractiveActionSectionProductItem(TypedDict, total=False):
    product_retailer_id: str


class WhatsappMessageInteractiveActionSectionRow(TypedDict, total=False):
    id: str
    """arbitrary string identifying the row, 200 character maximum"""

    description: str
    """row description, 72 character maximum"""

    title: str
    """row title, 24 character maximum"""


class WhatsappMessageInteractiveActionSection(TypedDict, total=False):
    product_items: Iterable[WhatsappMessageInteractiveActionSectionProductItem]

    rows: Iterable[WhatsappMessageInteractiveActionSectionRow]

    title: str
    """section title, 24 character maximum"""


class WhatsappMessageInteractiveAction(TypedDict, total=False):
    button: str

    buttons: Iterable[WhatsappMessageInteractiveActionButton]

    cards: Iterable[WhatsappMessageInteractiveActionCard]

    catalog_id: str

    mode: str

    name: str

    parameters: WhatsappMessageInteractiveActionParameters

    product_retailer_id: str

    sections: Iterable[WhatsappMessageInteractiveActionSection]


class WhatsappMessageInteractiveBody(TypedDict, total=False):
    text: str
    """body text, 1024 character maximum"""


class WhatsappMessageInteractiveFooter(TypedDict, total=False):
    text: str
    """footer text, 60 character maximum"""


class WhatsappMessageInteractiveHeader(TypedDict, total=False):
    document: WhatsappMediaParam

    image: WhatsappMediaParam

    sub_text: str

    text: str
    """header text, 60 character maximum"""

    video: WhatsappMediaParam


class WhatsappMessageInteractive(TypedDict, total=False):
    action: WhatsappMessageInteractiveAction

    body: WhatsappMessageInteractiveBody

    footer: WhatsappMessageInteractiveFooter

    header: WhatsappMessageInteractiveHeader

    type: Literal["cta_url", "list", "carousel", "button", "location_request_message"]


class WhatsappMessageLocation(TypedDict, total=False):
    address: str

    latitude: str

    longitude: str

    name: str


class WhatsappMessageReaction(TypedDict, total=False):
    emoji: str

    message_id: str


class WhatsappMessage(TypedDict, total=False):
    audio: WhatsappMediaParam

    biz_opaque_callback_data: str
    """custom data to return with status update"""

    contacts: Iterable[WhatsappMessageContact]

    document: WhatsappMediaParam

    image: WhatsappMediaParam

    interactive: WhatsappMessageInteractive

    location: WhatsappMessageLocation

    reaction: WhatsappMessageReaction

    sticker: WhatsappMediaParam

    type: Literal[
        "audio", "document", "image", "sticker", "video", "interactive", "location", "template", "reaction", "contacts"
    ]

    video: WhatsappMediaParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["AuthenticationProviderListParams"]


class AuthenticationProviderListParams(TypedDict, total=False):
    page_number: Annotated[int, PropertyInfo(alias="page[number]")]

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]

    sort: Literal[
        "name",
        "-name",
        "short_name",
        "-short_name",
        "active",
        "-active",
        "created_at",
        "-created_at",
        "updated_at",
        "-updated_at",
    ]
    """Specifies the sort order for results.

    By default sorting direction is ascending. To have the results sorted in
    descending order add the <code>-</code> prefix.<br/><br/> That is: <ul>

      <li>
        <code>name</code>: sorts the result by the
        <code>name</code> field in ascending order.
      </li>
      <li>
        <code>-name</code>: sorts the result by the
        <code>name</code> field in descending order.
      </li>
    </ul><br/>If not given, results are sorted by <code>created_at</code> in descending order.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union
from typing_extensions import Literal, Required, TypeAlias, TypedDict

from .transcription_engine_a_config_param import TranscriptionEngineAConfigParam
from .transcription_engine_b_config_param import TranscriptionEngineBConfigParam
from .transcription_engine_azure_config_param import TranscriptionEngineAzureConfigParam
from .transcription_engine_google_config_param import TranscriptionEngineGoogleConfigParam
from .transcription_engine_telnyx_config_param import TranscriptionEngineTelnyxConfigParam

__all__ = [
    "ActionStartTranscriptionParams",
    "TranscriptionEngineConfig",
    "TranscriptionEngineConfigDeepgramNova2Config",
    "TranscriptionEngineConfigDeepgramNova3Config",
]


class ActionStartTranscriptionParams(TypedDict, total=False):
    client_state: str
    """Use this field to add state to every subsequent webhook.

    It must be a valid Base-64 encoded string.
    """

    command_id: str
    """Use this field to avoid duplicate commands.

    Telnyx will ignore any command with the same `command_id` for the same
    `call_control_id`.
    """

    transcription_engine: Literal["Google", "Telnyx", "Deepgram", "Azure", "A", "B"]
    """Engine to use for speech recognition.

    Legacy values `A` - `Google`, `B` - `Telnyx` are supported for backward
    compatibility.
    """

    transcription_engine_config: TranscriptionEngineConfig

    transcription_tracks: str
    """Indicates which leg of the call will be transcribed.

    Use `inbound` for the leg that requested the transcription, `outbound` for the
    other leg, and `both` for both legs of the call. Will default to `inbound`.
    """


class TranscriptionEngineConfigDeepgramNova2Config(TypedDict, total=False):
    transcription_engine: Required[Literal["Deepgram"]]

    transcription_model: Required[Literal["deepgram/nova-2"]]

    keywords_boosting: Dict[str, float]
    """
    Keywords and their respective intensifiers (boosting values) to improve
    transcription accuracy for specific words or phrases. The intensifier should be
    a numeric value. Example: `{"snuffleupagus": 5, "systrom": 2, "krieger": 1}`.
    """

    language: Literal[
        "bg",
        "ca",
        "zh-CN",
        "zh-Hans",
        "zh-TW",
        "zh-Hant",
        "zh-HK",
        "cs",
        "da-DK",
        "nl-BE",
        "en-US",
        "en-AU",
        "en-GB",
        "en-NZ",
        "en-IN",
        "et",
        "fi",
        "fr",
        "fr-CA",
        "de-CH",
        "el",
        "hi",
        "hu",
        "id",
        "it",
        "ja",
        "ko-KR",
        "lv",
        "lt",
        "ms",
        "no",
        "pl",
        "pt-BR",
        "pt-PT",
        "ro",
        "ru",
        "sk",
        "es-419",
        "sv-SE",
        "th-TH",
        "tr",
        "uk",
        "vi",
        "auto_detect",
    ]
    """Language to use for speech recognition with nova-2 model"""


class TranscriptionEngineConfigDeepgramNova3Config(TypedDict, total=False):
    transcription_engine: Required[Literal["Deepgram"]]

    transcription_model: Required[Literal["deepgram/nova-3"]]

    keywords_boosting: Dict[str, float]
    """
    Keywords and their respective intensifiers (boosting values) to improve
    transcription accuracy for specific words or phrases. The intensifier should be
    a numeric value. Example: `{"snuffleupagus": 5, "systrom": 2, "krieger": 1}`.
    """

    language: Literal[
        "en-US",
        "en-AU",
        "en-GB",
        "en-IN",
        "en-NZ",
        "de",
        "nl",
        "sv-SE",
        "da-DK",
        "es",
        "es-419",
        "fr",
        "fr-CA",
        "pt-BR",
        "pt-PT",
        "auto_detect",
    ]
    """Language to use for speech recognition with nova-3 model"""


TranscriptionEngineConfig: TypeAlias = Union[
    TranscriptionEngineGoogleConfigParam,
    TranscriptionEngineTelnyxConfigParam,
    TranscriptionEngineConfigDeepgramNova2Config,
    TranscriptionEngineConfigDeepgramNova3Config,
    TranscriptionEngineAzureConfigParam,
    TranscriptionEngineAConfigParam,
    TranscriptionEngineBConfigParam,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .recording_transcription import RecordingTranscription

__all__ = ["RecordingTranscriptionListResponse", "Meta", "MetaCursors"]


class MetaCursors(BaseModel):
    after: Optional[str] = None
    """Opaque identifier of next page."""

    before: Optional[str] = None
    """Opaque identifier of previous page."""


class Meta(BaseModel):
    cursors: Optional[MetaCursors] = None

    next: Optional[str] = None
    """Path to next page."""

    previous: Optional[str] = None
    """Path to previous page."""


class RecordingTranscriptionListResponse(BaseModel):
    data: Optional[List[RecordingTranscription]] = None

    meta: Optional[Meta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PhoneNumberUpdateParams"]


class PhoneNumberUpdateParams(TypedDict, total=False):
    id: Required[str]

    location_id: str
    """Identifies the location to assign the phone number to."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from .._models import BaseModel
from .room_session import RoomSession

__all__ = ["Room"]


class Room(BaseModel):
    id: Optional[str] = None
    """A unique identifier for the room."""

    active_session_id: Optional[str] = None
    """The identifier of the active room session if any."""

    created_at: Optional[datetime] = None
    """ISO 8601 timestamp when the room was created."""

    enable_recording: Optional[bool] = None
    """Enable or disable recording for that room."""

    max_participants: Optional[int] = None
    """Maximum participants allowed in the room."""

    record_type: Optional[str] = None

    sessions: Optional[List[RoomSession]] = None

    unique_name: Optional[str] = None
    """The unique (within the Telnyx account scope) name of the room."""

    updated_at: Optional[datetime] = None
    """ISO 8601 timestamp when the room was updated."""

    webhook_event_failover_url: Optional[str] = None
    """
    The failover URL where webhooks related to this room will be sent if sending to
    the primary URL fails. Must include a scheme, such as 'https'.
    """

    webhook_event_url: Optional[str] = None
    """The URL where webhooks related to this room will be sent.

    Must include a scheme, such as 'https'.
    """

    webhook_timeout_secs: Optional[int] = None
    """Specifies how many seconds to wait before timing out a webhook."""
